Srt class

Global SRT instance for lifecycle management

Constructors

Srt()
Initialize the SRT library

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

addSocket SrtSocket
no getter
bindings → srt_dart_bindings
Get the bindings instance, initializing if necessary
no setter
removeSocket SrtSocket
no getter

Static Methods

cleanUp() → void
Clean up the SRT library and release all resources